<?php
/**
 * Classic Posts Block.
 *
 * @category   Class
 * @package    ConeBlogWidgets
 * @subpackage WordPress
 */

namespace ConeBlogWidgets\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Core\Schemes\Color;
use ConeBlogWidgets\Classes\Helper;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * FeaturedGrid widget class.
 *
 * @since 1.0.0
 */
class coneblog_Classic_Posts extends Widget_Base {

	/**
	 * Class constructor.
	 *
	 * @param array $data Widget data.
	 * @param array $args Widget arguments.
	 */
	public function __construct( $data = array(), $args = null ) {
		parent::__construct( $data, $args );

		wp_register_style( 'coneblog-posts-classic', plugins_url( '/assets/css/posts-classic.css', CONEBLOG_WIDGETS ), array(), '1.0.0' );

	}

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'coneblog_posts_classic';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Classic Posts', 'coneblog-widgets' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'coneblog-icon-posts-classic';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'coneblog-widgets' );
	}
	
	/**
	 * Enqueue styles.
	 */
	public function get_style_depends() {
		return array( 'coneblog-posts-classic' );
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$post_types = Helper::coneblog_get_post_types();
		$taxonomies = get_taxonomies([], 'objects');

		/**
		 * The Layout Tab
		 * 
		 */
		$this->start_controls_section(
			'section_layout',
			array(
				'label' => __( 'Layout', 'coneblog-widgets' ),
			)
        );
        $this->add_control(
			'layout',
			array(
				'label'   => __( 'List Layout', 'coneblog-widgets' ),
				'type'    => Controls_Manager::SELECT,
				'default' => __( '1', 'coneblog-widgets' ),
				'options' => ['1' => 'Layout 1', '2' => 'Layout 2', '3' => 'Layout 3'],
			)
        );
        $this->add_control(
			'show_widget_head',
			array(
				'label'   => __( 'Widget Heading', 'coneblog-widgets' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'coneblog-widgets' ),
				'label_off' => __( 'Hide', 'coneblog-widgets' ),
				'return_value' => 'yes',
				'default' => 'yes',
			)
		);
        $this->add_control(
			'widget_head_text',
			array(
				'label'   => __( 'Widget Heading Text', 'coneblog-widgets' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __( 'Posts List', 'coneblog-widgets' ),
				'condition' => [ 'show_widget_head' => 'yes' ]
			)
		);
		$this->add_control(
			'show_term',
			array(
				'label'   => __( 'Post Term', 'coneblog-widgets' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'coneblog-widgets' ),
				'label_off' => __( 'Hide', 'coneblog-widgets' ),
				'return_value' => 'yes',
				'default' => 'yes',
			)
		);
		$this->add_control(
			'show_meta',
			array(
				'label'   => __( 'Post Meta', 'coneblog-widgets' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'coneblog-widgets' ),
				'label_off' => __( 'Hide', 'coneblog-widgets' ),
				'return_value' => 'yes',
				'default' => 'yes',
			)
        );
        $this->add_control(
			'show_excerpt',
			array(
				'label'   => __( 'Post Excerpt', 'coneblog-widgets' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'coneblog-widgets' ),
				'label_off' => __( 'Hide', 'coneblog-widgets' ),
				'return_value' => 'yes',
				'default' => 'yes',
			)
		);
		$this->end_controls_section();

		/**
		 * The Query Tab
		 * 
		 */
		$this->start_controls_section(
			'section_query',
			array(
				'label' => __( 'Query', 'coneblog-widgets' ),
			)
		);

		$this->add_control(
            'post_type',
            [
                'label' => __('Source', 'coneblog-widgets'),
                'type' => Controls_Manager::SELECT,
                'options' => $post_types,
                'default' => key($post_types),
            ]
		);
		foreach ($taxonomies as $taxonomy => $object) {
            if (!isset($object->object_type[0]) || !in_array($object->object_type[0], array_keys($post_types))) {
                continue;
            }

            $this->add_control(
                $taxonomy . '_ids',
                [
                    'label' => $object->label,
                    'type' => Controls_Manager::SELECT2,
                    'label_block' => true,
                    'multiple' => true,
                    'object_type' => $taxonomy,
                    'options' => wp_list_pluck(get_terms($taxonomy), 'name', 'term_id'),
                    'condition' => [
                        'post_type' => $object->object_type,
                    ],
                ]
            );
        }

        $this->add_control(
            'posts_per_page',
            [
                'label' => __('Posts Per Page', 'coneblog-widgets'),
                'type' => Controls_Manager::NUMBER,
                'default' => '4',
            ]
        );

        $this->add_control(
            'offset',
            [
                'label' => __('Offset', 'coneblog-widgets'),
                'type' => Controls_Manager::NUMBER,
                'default' => '0',
            ]
        );

        $this->add_control(
            'orderby',
            [
                'label' => __('Order By', 'coneblog-widgets'),
                'type' => Controls_Manager::SELECT,
                'options' => Helper::coneblog_get_post_orderby_options(),
                'default' => 'date',

            ]
        );

        $this->add_control(
            'order',
            [
                'label' => __('Order', 'coneblog-widgets'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'asc' => 'Ascending',
                    'desc' => 'Descending',
                ],
                'default' => 'desc',

            ]
        );
		$this->end_controls_section();

		/**
         * Typography 
         */
        $this->start_controls_section(
            'coneblog_section_typography',
            [
                'label' => __('Typography', 'coneblog-widgets'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'coneblog_post_list_widget_head',
            [
                'label' => __('Widget Head', 'coneblog-widgets'),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'coneblog_post_list_widget_head_typography',
                'label' => __('Typography', 'coneblog-widgets'),
                'scheme' => Typography::TYPOGRAPHY_1,
                'selector' =>
					'{{WRAPPER}} .coneblog-widget-head h3',
            ]
        );
        $this->add_control(
            'coneblog_post_list_widget_head_bg',
            [
                'label' => __('Widget Head Background', 'coneblog-widgets'),
                'type' => Controls_Manager::COLOR,
                'default' => '#f6ce2b',
                'selectors' => [
                    '{{WRAPPER}} .coneblog-widget-head' => 'border-color: {{VALUE}};',
                    '{{WRAPPER}} .coneblog-widget-head h3' => 'background-color: {{VALUE}};',
                ],

            ]
        );
        $this->add_control(
            'coneblog_post_list_widget_head_text',
            [
                'label' => __('Widget Head Text Color', 'coneblog-widgets'),
                'type' => Controls_Manager::COLOR,
                'default' => '#000000',
                'selectors' => [
                    '{{WRAPPER}} .coneblog-widget-head h3' => 'color: {{VALUE}};',
                ],

            ]
        );

        $this->add_control(
            'coneblog_post_list_title_style',
            [
                'label' => __('Post Content', 'coneblog-widgets'),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'coneblog_post_list_title_color',
            [
                'label' => __('Post Title Color', 'coneblog-widgets'),
                'type' => Controls_Manager::COLOR,
                'default' => '#333333',
                'selectors' => [
                    '{{WRAPPER}} .coneblog-posts-classic .item-meta .post-title a' => 'color: {{VALUE}};',
                ],

            ]
        );

        $this->add_control(
            'coneblog_post_list_title_hover_color',
            [
                'label' => __('Post Title Hover Color', 'coneblog-widgets'),
                'type' => Controls_Manager::COLOR,
                'default' => '#f6ce2b',
                'selectors' => [
                    '{{WRAPPER}} .coneblog-posts-classic .item-meta .post-title a:hover' => 'color: {{VALUE}};',
                ],

            ]
        );
        $this->add_control(
            'coneblog_post_meta_color',
            [
                'label' => __('Post Meta Color', 'coneblog-widgets'),
                'type' => Controls_Manager::COLOR,
                'default' => '#555555',
                'selectors' => [
                    '{{WRAPPER}} .coneblog-posts-classic .list-item .list-meta-info' => 'color: {{VALUE}};',
					'{{WRAPPER}} .coneblog-posts-classic .list-item .list-meta-info a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .coneblog-posts-classic .list-item .list-meta-info i' => 'color: {{VALUE}};',
                ],

            ]
        );
        $this->add_responsive_control(
            'coneblog_post_list_title_alignment',
            [
                'label' => __('Text Alignment', 'coneblog-widgets'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => __('Left', 'coneblog-widgets'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => __('Center', 'coneblog-widgets'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => __('Right', 'coneblog-widgets'),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'selectors' => [
					'{{WRAPPER}} .coneblog-posts-classic .item-meta' => 'text-align: {{VALUE}};',
					'{{WRAPPER}} .coneblog-posts-classic .item-meta .post-title' => 'text-align: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'coneblog_post_list_title_large_typography',
                'label' => __('Post Title (Large Grid)', 'coneblog-widgets'),
                'scheme' => Typography::TYPOGRAPHY_1,
                'selector' =>
					'{{WRAPPER}} .coneblog-posts-classic .item-1 .item-meta .post-title',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'coneblog_post_list_title_typography',
                'label' => __('Post Title (Small Grids)', 'coneblog-widgets'),
                'scheme' => Typography::TYPOGRAPHY_1,
                'selector' =>
					'{{WRAPPER}} .coneblog-posts-classic .item-meta .post-title',
            ]
        );
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'coneblog_post_list_title_typography_2',
                'label' => __('Post Excerpt', 'coneblog-widgets'),
                'scheme' => Typography::TYPOGRAPHY_2,
                'selector' => '{{WRAPPER}} .coneblog-posts-classic .item-meta .post-desc',
            ]
        );
		$this->add_group_control(
			\Elementor\Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'coneblog_post_list_title_text_shadow',
				'label' => __( 'Text Shadow', 'coneblog-widgets' ),
				'selector' => '{{WRAPPER}} .featured-grid-item .featured-meta-inner h3 a',
			]
		);
        $this->end_controls_section();
        
		/**
         * Post Term
         */
        $this->start_controls_section(
            'coneblog_section_post_term',
            [
                'label' => __('Post Term', 'coneblog-widgets'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
		);
		$this->add_control(
			'coneblog_post_term_icon_bg',
			[
				'label' => __( 'Term Icon Background', 'coneblog-widgets' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .coneblog-posts-classic .list-item .grid-post-term span.term-icon' => 'background-color: {{VALUE}}',
				],
				'default' => 'rgba(0, 0, 0, 1)',
			]
		);
		$this->add_control(
			'coneblog_post_term_icon_color',
			[
				'label' => __( 'Term Icon Color', 'coneblog-widgets' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .coneblog-posts-classic .list-item .grid-post-term span.term-icon' => 'color: {{VALUE}}',
				],
				'default' => 'rgba(255, 255, 255, 1)',
			]
		);
		$this->add_control(
			'coneblog_post_term_name_bg',
			[
				'label' => __( 'Term Name Background', 'coneblog-widgets' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .coneblog-posts-classic .list-item .grid-post-term span.term-name' => 'background-color: {{VALUE}}',
				],
				'default' => '#f6ce2b',
			]
		);
		$this->add_control(
			'coneblog_post_term_name_color',
			[
				'label' => __( 'Term Name Color', 'coneblog-widgets' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .coneblog-posts-classic .list-item .grid-post-term span.term-name' => 'color: {{VALUE}}',
				],
				'default' => '#000000',
			]
		);
		
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		$this->add_inline_editing_attributes( 'layout', 'none' );
		$layout = $settings['layout'];
        $i = 1;
        $args = Helper::coneblog_get_query_args($settings);
		?>
            <div class="coneblog-posts-classic-container">
                <?php
                    if ( 'yes' === $settings['show_widget_head'] ) { ?>
                <div class="coneblog-widget-head">
                    <h3><?php echo $settings['widget_head_text'] ?></h3>
				</div>
				<?php } ?>
                <div class="coneblog-posts-classic layout-<?php echo $layout ?>">
                    <?php
                    $list_posts = new \WP_Query($args);
                    if($list_posts->have_posts()) {
                        while($list_posts->have_posts()):
                            $list_posts->the_post();
                    ?>
                    <?php if($i === 1): ?>
                        <div class="list-item<?php echo ($layout == 1 || $layout == 2 ? ' item-1' : '') ?>">
                            <div class="item-thumb">
                                <a href="<?php the_permalink() ?>">
                                    <?php
                                        if(has_post_thumbnail()):
                                            the_post_thumbnail('coneblog-classic-thumb-large');
                                        else:
                                            echo '<img src="'.CONEBLOG_ASSETS_PATH.'img/thumb-medium.png">';
                                        endif;
                                    ?>
                                </a>
                                <?php
                                    if ( 'yes' === $settings['show_term'] ) {
                                        Helper::coneblog_post_term_box();
                                    }
                                ?>
                            </div>
                            <div class="item-meta">
                                <h4 class="post-title"><a href="<?php the_permalink() ?>"><?php the_title(); ?></a></h4>
                                <?php
                                if ( 'yes' === $settings['show_meta'] ) { ?>
                                    <span class="list-meta-info d-block">
                                        <?php Helper::coneblog_posted_by() ?> <?php Helper::coneblog_posted_on() ?> <?php Helper::coneblog_entry_comments() ?>
                                    </span>
                                <?php } ?>
                                <?php
                                if ( 'yes' === $settings['show_excerpt'] ) { ?>
                                    <p class="post-desc"><?php echo ($layout == 1 || $layout == 2 ? Helper::coneblog_list_excerpt(25) : Helper::coneblog_list_excerpt(50)) ?></p>
                                <?php } ?>
                                
                            </div>
                        </div>
                    <?php else: ?>
                        <div class="list-item">
                            <div class="item-thumb">
                                <a href="<?php the_permalink() ?>">
                                    <?php
                                        if(has_post_thumbnail()):
                                            the_post_thumbnail('coneblog-classic-thumb');
                                        else:
                                            echo '<img src="'.CONEBLOG_ASSETS_PATH.'img/thumb-classic.png">';
                                        endif;
                                    ?>
                                </a>
                                <?php
                                    if ( 'yes' === $settings['show_term'] ) {
                                        Helper::coneblog_post_term_box();
                                    }
                                ?>
                            </div>
                            <div class="item-meta">
                                <h4 class="post-title"><a href="<?php the_permalink() ?>"><?php the_title(); ?></a></h4>
                                <?php
                                if ( 'yes' === $settings['show_meta'] ) { ?>
                                    <span class="list-meta-info d-block">
                                        <?php Helper::coneblog_posted_by() ?> <?php Helper::coneblog_posted_on() ?> <?php Helper::coneblog_entry_comments() ?>
                                    </span>
                                <?php } ?>
                                <?php
                                if ( 'yes' === $settings['show_excerpt'] ) { ?>
                                    <p class="post-desc"><?php echo ( $layout == 1 || $layout == 2 ? Helper::coneblog_list_excerpt(15) : Helper::coneblog_list_excerpt(50) )?></p>
                                <?php } ?>
                                
                            </div>
                        </div>
                    <?php endif; ?>
                    <?php $i++; endwhile;  }
                        \wp_reset_postdata();
                    ?>
                </div>
                
            </div>
		<?php
	}


}
